@@ -12,10 +12,11 @@ use namespace::clean;
 extends 'Code::TidyAll::Plugin';
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = '0.002';
+our $VERSION   = '0.003';
 
-has 'indent' => ( is => 'ro', default => sub {"\t"} );
-has 'style'  => ( is => 'ro', default => sub {'cvs'} );
+has 'indent'   => ( is => 'ro', default => sub {"\t"} );
+has 'style'    => ( is => 'ro', default => sub {'cvs'} );
+has 'comments' => ( is => 'ro', default => sub {'keep'} );
 
 sub transform_file
 {
@@ -25,6 +26,7 @@ sub transform_file
 	my $svg = XML::Twig->new(
 		keep_encoding => 1,
 		pretty_print  => $self->style,
+		comments      => $self->comments,
 		twig_handlers => {
 			_all_ => sub { $_[0]->flush; },
 		}
@@ -48,7 +50,7 @@ Code::TidyAll::Plugin::SVG - optimize SVG files with tidyall
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -79,6 +81,12 @@ Indentation string.
 
 Default is a single TAB (i.e. C<\t>).
 
+=item comments
+
+How to treat comments (as defined by L<XML::Twig>.
+
+Default is to keep comments.
+
 =back
 
 =head1 SEE ALSO
@@ -93,7 +101,7 @@ Jonas Smedegaard <dr@jones.dk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jonas Smedegaard.
+This software is copyright (c) 2014-2016 by Jonas Smedegaard.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
